from pathlib import Path
import appdirs
import json

_urlbase = "bionano.physics.illinois.edu"


""" Get configuration file for mrdna """
_USER_CONF_DIR = Path(appdirs.user_data_dir())
_USER_CONF_DIR.mkdir(parents=True, exist_ok=True)
_USER_CONF = _USER_CONF_DIR / "mrdna.conf"

CACHE_DIR = _USER_CONF_DIR / "mrdna.cache"
CACHE_DIR.mkdir(parents=True, exist_ok=True)


if _USER_CONF.exists():
    with open(_USER_CONF) as ch:
        config = json.load(ch)
else:
    config = {}
    print("""Thanks for using the multi-resolution DNA modeling package mrdna!

PRIVACY STATEMENT AND USER AGREEMENT:

We respect your privacy. We will never collect or share your
information without your explicit permission.

At the same time, we would like to collect anonymous statistics about
the use of the mrdna Python package for reporting to funding agencies
so we can continue to develop and improve these utilities.

For this, we ask for your permission to have the mrdna utility send
your IP address along with information about what part of the mrdna
utility you are using (e.g. cadnano reader, vHelix reader, mrdna
script) to our webserver where it will be stored in a database, along
with geolocation data and a timestamp. Except for your IP adress, no
personally identifiable information will be stored. You are not
required to opt-in to use the mrdna package!

If you have concerns regarding your privacy, please contact the
Aksimentiev group and we will get back to you as soon as we can.
mailto:cmaffeo2@illinois.edu""")
    while True:
        print("""
Do you agree to allow the mrdna package can send the information
described above to the Aksimentiev group webserver? [y/N]""")
        response = input()
        if response in 'y Y yes Yes YES'.split():
            # print("Permission granted")
            config['reporting_allowed'] = True
            break
        elif response in 'n N no No NO'.split() + [""]:
            # print("Permission denied")
            config['reporting_allowed'] = False
            break
    with open(_USER_CONF,'w') as ch:
        json.dump(config,ch)
