from ..segmentmodel import SegmentModel

""" cadnano """
from .cadnano_segments import read_json_file
from .cadnano_segments import read_model as model_from_cadnano_json

""" vHelix """
from .polygon_mesh import parse_maya_file, convert_maya_to_segments
from ..model.dna_sequence import m13 as m13seq

""" Atomic PDB """
from .segmentmodel_from_pdb import SegmentModelFromPdb

## TODO: make module this package conform to a single style for input/output

def read_cadnano(json_file, **model_parameters):
    data = read_json_file(json_file)
    return model_from_cadnano_json(data)

def read_vhelix(maya_file, **model_parameters):
    data = parse_maya_file(maya_file)
    segments, dsSegmentDict = convert_maya_to_segments( data )
    if 'dimensions' not in model_parameters:
        model_parameters['dimensions']=(5000,5000,5000)
    model = SegmentModel( segments,**model_parameters )
    model.set_sequence(m13seq*10)
    return model

def read_list(infile,**model_parameters):
    import numpy as np
    try:
        data = np.loadtxt(infile)
    except:
        data = np.loadtxt(infile,skiprows=1) # strip header
    coords = data[:,:3]*10
    bp = data[:,3]
    stack = data[:,4]
    three_prime = data[:,5]

    from .segmentmodel_from_lists import model_from_basepair_stack_3prime
    return model_from_basepair_stack_3prime(coords, bp, stack, three_prime)


def read_atomic_pdb(pdb_file, **model_parameters):
    return SegmentModelFromPdb(pdb_file)
